## dbt-bigquery 1.10.1 - July 29, 2025

### Features

- Support impersonate service account in bigframes mode ([#1202](https://github.com/dbt-labs/dbt-adapters/issues/1202))

### Fixes

- Add support for copy_partitions when used with static partitions. ([#540](https://github.com/dbt-labs/dbt-adapters/issues/540))
- Track notebook job status to avoid LRO in bigframes mode ([#1175](https://github.com/dbt-labs/dbt-adapters/issues/1175))

### Contributors
- [@Kayrnt](https://github.com/Kayrnt) ([#540](https://github.com/dbt-labs/dbt-adapters/issues/540))
- [@jialuoo](https://github.com/jialuoo) ([#1202](https://github.com/dbt-labs/dbt-adapters/issues/1202), [#1175](https://github.com/dbt-labs/dbt-adapters/issues/1175))
